@@ -1,28 +1,71 @@
 package Text::Template::Simple::Base::Compiler;
 use strict;
+use warnings;
 use vars qw($VERSION);
 use Text::Template::Simple::Util qw(:all);
 use Text::Template::Simple::Constants qw(:all);
 
-$VERSION = '0.81';
+$VERSION = '0.82';
 
-sub _compiler { shift->[SAFE] ? COMPILER_SAFE : COMPILER }
+sub _init_compile_opts {
+   my $self = shift;
+   my $opt  = shift || {};
+
+   fatal('tts.base.compiler._compile.opt')   if not ishref($opt  );
+
+   # set defaults
+   $opt->{id}       ||= EMPTY_STRING; # id is AUTO
+   $opt->{map_keys} ||= 0;  # use normal behavior
+   $opt->{chkmt}    ||= 0;  # check mtime of file template?
+   $opt->{_sub_inc} ||= 0;  # are we called from a dynamic include op?
+   $opt->{_filter}  ||= EMPTY_STRING; # any filters?
+
+   # first element is the shared names. if it's not defined, then there
+   # are no shared variables from top level
+   delete $opt->{_share}
+      if isaref($opt->{_share}) && ! defined $opt->{_share}[0];
+
+   $opt->{as_is} = $opt->{_sub_inc} && $opt->{_sub_inc} == T_STATIC;
+
+   return $opt;
+}
+
+sub _validate_chkmt {
+   my($self, $chkmt_ref, $tmpx) = @_;
+   ${$chkmt_ref} = $self->[TYPE] eq 'FILE'
+                 ? (stat $tmpx)[STAT_MTIME]
+                 : do {
+                     DEBUG && LOG( DISABLE_MT =>
+                                    'Disabling chkmt. Template is not a file');
+                     0;
+                  };
+   return;
+}
+
+sub _compile_cache {
+   my($self, $tmp, $opt, $id_ref, $code_ref) = @_;
+   my $method   = $opt->{id};
+   my $auto_id  = ! $method || $method eq 'AUTO';
+   ${ $id_ref } = $self->connector('Cache::ID')->new->generate(
+                     $auto_id ? ( $tmp ) : ( $method, 'custom' )
+                  );
+
+   # prevent overwriting the compiled version in cache
+   # since we need the non-compiled version
+   ${ $id_ref } .= '_1' if $opt->{as_is};
+
+   ${ $code_ref } = $self->cache->hit( ${$id_ref}, $opt->{chkmt} );
+   LOG( CACHE_HIT =>  ${$id_ref} ) if DEBUG && ${$code_ref};
+   return;
+}
 
 sub _compile {
    my $self  = shift;
    my $tmpx  = shift || fatal('tts.base.compiler._compile.notmp');
    my $param = shift || [];
-   my $opt   = shift || {};
+   my $opt   = $self->_init_compile_opts( shift );
 
-   fatal('tts.base.compiler._compile.param') if not isaref($param);
-   fatal('tts.base.compiler._compile.opt')   if not ishref($opt  );
-
-   # set defaults
-   $opt->{id}       ||= ''; # id is AUTO
-   $opt->{map_keys} ||= 0;  # use normal behavior
-   $opt->{chkmt}    ||= 0;  # check mtime of file template?
-   $opt->{_sub_inc} ||= 0;  # are we called from a dynamic include op?
-   $opt->{_filter}  ||= ''; # any filters?
+   fatal('tts.base.compiler._compile.param') if ! isaref($param);
 
    my $tmp = $self->_examine( $tmpx );
    return $tmp if $self->[TYPE] eq 'ERROR';
@@ -38,43 +81,14 @@ sub _compile {
       $self->[NEEDS_OBJECT]++; # interpolated includes will need that
    }
 
-   if ( $opt->{chkmt} ) {
-      $opt->{chkmt} = $self->[TYPE] eq 'FILE' ? (stat $tmpx)[STAT_MTIME]
-                    : do {
-                        DEBUG && LOG(DISABLE_MT =>
-                                     "Disabling chkmt. Template is not a file");
-                        0;
-                     }
-   }
+   $self->_validate_chkmt( \$opt->{chkmt}, $tmpx ) if $opt->{chkmt};
 
    LOG( COMPILE => $opt->{id} ) if DEBUG && defined $opt->{id};
 
-   my($CODE, $ok);
-   my $cache_id = '';
+   my $cache_id = EMPTY_STRING;
 
-   my $as_is = $opt->{_sub_inc} && $opt->{_sub_inc} == T_STATIC;
-
-   # first element is the shared names. if it's not defined, then there
-   # are no shared variables from top level
-   delete $opt->{_share}
-      if isaref($opt->{_share}) && ! defined $opt->{_share}[0];
-
-   if ( $self->[CACHE] ) {
-      my $method = $opt->{id};
-      my @args   = (! $method || $method eq 'AUTO') ? ( $tmp              )
-                 :                                    ( $method, 'custom' )
-                 ;
-      $cache_id  = $self->connector('Cache::ID')->new->generate( @args );
-
-      # prevent overwriting the compiled version in cache
-      # since we need the non-compiled version
-      $cache_id .= '_1' if $as_is;
-
-      if ( $CODE = $self->cache->hit( $cache_id, $opt->{chkmt} ) ) {
-         LOG( CACHE_HIT =>  $cache_id ) if DEBUG();
-         $ok = 1;
-      }
-   }
+   my($CODE);
+   $self->_compile_cache( $tmp, $opt, \$cache_id, \$CODE ) if $self->[CACHE];
 
    $self->cache->id( $cache_id ); # if $cache_id;
    $self->[FILENAME] = $self->[TYPE] eq 'FILE' ? $tmpx : $self->cache->id;
@@ -85,25 +99,7 @@ sub _compile {
       SHARED_VARS => "Adding shared variables ($shead) from a dynamic include"
    ) if DEBUG && $shead;
 
-   if ( not $ok ) {
-      # we have a cache miss; parse and compile
-      LOG( CACHE_MISS => $cache_id ) if DEBUG();
-
-      my $shared;
-      if ( $shead ) {
-         my $param = join ',', ('shift') x @sparam;
-         $shared = sprintf qq~my(%s) = (%s);~, $shead, $param;
-      }
-
-      local $self->[HEADER] = do {
-         my $old = $self->[HEADER] || '';
-         $shared . ';' . $old
-      } if $shared;
-
-      my %popt   = ( %{ $opt }, cache_id => $cache_id, as_is => $as_is );
-      my $parsed = $self->_parse( $tmp, \%popt );
-      $CODE      = $self->cache->populate( $cache_id, $parsed, $opt->{chkmt} );
-   }
+   $CODE = $self->_cache_miss( $cache_id, $shead, \@sparam, $opt, $tmp ) if ! $CODE;
 
    my @args;
    push @args, $self   if $self->[NEEDS_OBJECT]; # must be the first
@@ -118,16 +114,34 @@ sub _compile {
    return $out;
 }
 
+sub _cache_miss {
+   my($self, $cache_id, $shead, $sparam, $opt, $tmp) = @_;
+   # we have a cache miss; parse and compile
+   LOG( CACHE_MISS => $cache_id ) if DEBUG;
+
+   my $restore_header;
+   if ( $shead ) {
+      my $param_x = join q{,}, ('shift') x @{ $sparam };
+      my $shared  = sprintf q~my(%s) = (%s);~, $shead, $param_x;
+      $restore_header = $self->[HEADER];
+      $self->[HEADER] = $shared . q{;} . ( $self->[HEADER] || EMPTY_STRING );
+   }
+
+   my %popt   = ( %{ $opt }, cache_id => $cache_id, as_is => $opt->{as_is} );
+   my $parsed = $self->_parse( $tmp, \%popt );
+   my $CODE      = $self->cache->populate( $cache_id, $parsed, $opt->{chkmt} );
+   $self->[HEADER] = $restore_header if $shead;
+   return $CODE;
+}
+
 sub _call_filters {
-   my $self    = shift;
-   my $oref    = shift;
-   my @filters = @_;
-   my $fname   = $self->[FILENAME];
+   my($self, $oref, @filters) = @_;
+   my $fname = $self->[FILENAME];
 
    APPLY_FILTERS: foreach my $filter ( @filters ) {
-      my $fref = DUMMY_CLASS->can( "filter_" . $filter );
+      my $fref = DUMMY_CLASS->can( 'filter_' . $filter );
       if ( ! $fref ) {
-         $$oref .= "\n[ filter warning ] Can not apply undefined filter"
+         ${$oref} .= "\n[ filter warning ] Can not apply undefined filter"
                 .  " $filter to $fname\n";
          next;
       }
@@ -141,10 +155,12 @@ sub _wrap_compile {
    my $self   = shift;
    my $parsed = shift or fatal('tts.base.compiler._wrap_compile.parsed');
    LOG( CACHE_ID => $self->cache->id ) if $self->[WARN_IDS] && $self->cache->id;
-   LOG( COMPILER => $self->[SAFE] ? 'Safe' : 'Normal' ) if DEBUG();
+   LOG( COMPILER => $self->[SAFE] ? 'Safe' : 'Normal' ) if DEBUG;
    my($CODE, $error);
 
-   $CODE = $self->_compiler->_compile($parsed);
+   my $compiler = $self->[SAFE] ? COMPILER_SAFE : COMPILER;
+
+   $CODE = $compiler->compile( $parsed );
 
    if( $error = $@ ) {
       my $error2;
@@ -165,7 +181,8 @@ sub _mini_compiler {
    fatal('tts.base.compiler._mini_compiler.param') if ! ishref($param);
 
    foreach my $var ( keys %{ $param } ) {
-      $template =~ s[<%\Q$var\E%>][$param->{$var}]xmsg;
+      my $str = $param->{$var};
+      $template =~ s{<%\Q$var\E%>}{$str}xmsg;
    }
 
    $template =~ s{\s+}{ }xmsg if $opt->{flatten}; # remove extra spaces
@@ -176,6 +193,8 @@ sub _mini_compiler {
 
 __END__
 
+=pod
+
 =head1 NAME
 
 Text::Template::Simple::Base::Compiler - Base class for Text::Template::Simple
@@ -186,8 +205,8 @@ Private module.
 
 =head1 DESCRIPTION
 
-This document describes version C<0.81> of C<Text::Template::Simple::Base::Compiler>
-released on C<13 September 2009>.
+This document describes version C<0.82> of C<Text::Template::Simple::Base::Compiler>
+released on C<30 May 2010>.
 
 Private module.
 
@@ -197,12 +216,12 @@ Burak Gursoy <burak@cpan.org>.
 
 =head1 COPYRIGHT
 
-Copyright 2004 - 2009 Burak Gursoy. All rights reserved.
+Copyright 2004 - 2010 Burak Gursoy. All rights reserved.
 
 =head1 LICENSE
 
 This library is free software; you can redistribute it and/or modify 
-it under the same terms as Perl itself, either Perl version 5.10.0 or, 
+it under the same terms as Perl itself, either Perl version 5.10.1 or, 
 at your option, any later version of Perl 5 you may have available.
 
 =cut
