@@ -1,5 +1,6 @@
 package Text::Template::Simple::Caller;
 use strict;
+use warnings;
 use vars qw($VERSION);
 use constant PACKAGE    => 0;
 use constant FILENAME   => 1;
@@ -11,23 +12,24 @@ use constant EVALTEXT   => 6;
 use constant IS_REQUIRE => 7;
 use constant HINTS      => 8;
 use constant BITMASK    => 9;
-use Text::Template::Simple::Util qw( ishref fatal );
+use Text::Template::Simple::Util      qw( ishref fatal );
+use Text::Template::Simple::Constants qw( EMPTY_STRING );
 
-$VERSION = '0.81';
+$VERSION = '0.82';
 
 sub stack {
    my $self    = shift;
    my $opt     = shift || {};
    fatal('tts.caller.stack.hash') if ! ishref($opt);
    my $frame   = $opt->{frame} || 0;
-   my $type    = $opt->{type}  || '';
+   my $type    = $opt->{type}  || EMPTY_STRING;
    my(@callers, $context);
 
    TRACE: while ( my @c = caller ++$frame ) {
 
       INITIALIZE: foreach my $id ( 0 .. $#c ) {
          next INITIALIZE if $id == WANTARRAY; # can be undef
-         $c[$id] ||= '';
+         $c[$id] ||= EMPTY_STRING;
       }
 
       $context = defined $c[WANTARRAY] ?  ( $c[WANTARRAY] ? 'LIST' : 'SCALAR' )
@@ -57,7 +59,7 @@ sub stack {
       return $self->$method( $opt, \@callers );
    }
 
-   fatal('tts.caller.stack.type', $type);
+   return fatal('tts.caller.stack.type', $type);
 }
 
 sub _string {
@@ -66,7 +68,7 @@ sub _string {
    my $callers = shift;
    my $is_html = shift;
 
-   my $name = $opt->{name} ? "FOR $opt->{name} " : "";
+   my $name = $opt->{name} ? "FOR $opt->{name} " : EMPTY_STRING;
    my $rv   = qq{[ DUMPING CALLER STACK $name]\n\n};
 
    foreach my $c ( reverse @{$callers} ) {
@@ -82,16 +84,33 @@ sub _string {
 }
 
 sub _html_comment {
-   shift->_string( @_, 'add html comment' );
+   my($self, @args) = @_;
+   return $self->_string( @args, 'add html comment' );
 }
 
 sub _html_table {
    my $self    = shift;
    my $opt     = shift;
    my $callers = shift;
-   my $rv      = q{
+   my $rv      = EMPTY_STRING;
+
+   foreach my $c ( reverse @{ $callers } ) {
+      $self->_html_table_blank_check( $c ); # modifies  in place
+      $rv .= $self->_html_table_row(  $c )
+   }
+
+   return $self->_html_table_wrap( $rv );
+}
+
+sub _html_table_wrap {
+   my($self, $content) = @_;
+   return <<"HTML";
    <div id="ttsc-wrapper">
-   <table border="1" cellpadding="1" cellspacing="2" id="ttsc-dump">
+   <table border      = "1"
+          cellpadding = "1"
+          cellspacing = "2"
+          id          = "ttsc-dump"
+      >
       <tr>
          <td class="ttsc-title">CONTEXT</td>
          <td class="ttsc-title">SUB</td>
@@ -103,76 +122,79 @@ sub _html_table {
          <td class="ttsc-title">HINTS</td>
          <td class="ttsc-title">BITMASK</td>
       </tr>
-   };
+      $content
+      </table>
+   </div>
+HTML
+}
 
-   foreach my $c ( reverse @{$callers} ) {
-      $self->_html_table_blank_check( $c ); # modifies  in place
-      $rv .= qq{
-      <tr>
-         <td class="ttsc-value">$c->{context}</td>
-         <td class="ttsc-value">$c->{sub}</td>
-         <td class="ttsc-value">$c->{line}</td>
-         <td class="ttsc-value">$c->{file}</td>
-         <td class="ttsc-value">$c->{hasargs}</td>
-         <td class="ttsc-value">$c->{isreq}</td>
-         <td class="ttsc-value">$c->{evaltext}</td>
-         <td class="ttsc-value">$c->{hints}</td>
-         <td class="ttsc-value">$c->{bitmask}</td>
-      </tr>
-      };
-   }
-
-   return $rv . q{</table></div>};
+sub _html_table_row {
+   my($self,$c) = @_;
+   return <<"HTML";
+   <tr>
+      <td class="ttsc-value">$c->{context}</td>
+      <td class="ttsc-value">$c->{sub}</td>
+      <td class="ttsc-value">$c->{line}</td>
+      <td class="ttsc-value">$c->{file}</td>
+      <td class="ttsc-value">$c->{hasargs}</td>
+      <td class="ttsc-value">$c->{isreq}</td>
+      <td class="ttsc-value">$c->{evaltext}</td>
+      <td class="ttsc-value">$c->{hints}</td>
+      <td class="ttsc-value">$c->{bitmask}</td>
+   </tr>
+HTML
 }
 
 sub _html_table_blank_check {
    my $self   = shift;
    my $struct = shift;
    foreach my $id ( keys %{ $struct }) {
-      if ( not defined $struct->{ $id } or $struct->{ $id } eq '' ) {
+      if ( not defined $struct->{ $id } or $struct->{ $id } eq EMPTY_STRING ) {
          $struct->{ $id } = '&#160;';
       }
    }
+   return;
 }
 
 sub _text_table {
    my $self    = shift;
    my $opt     = shift;
    my $callers = shift;
-   eval { require Text::Table; };
-   fatal('tts.caller._text_table.module', $@) if $@;
+   my $ok      = eval { require Text::Table; 1; };
+   fatal('tts.caller._text_table.module', $@) if ! $ok;
 
    my $table = Text::Table->new( qw(
                   | CONTEXT    | SUB      | LINE  | FILE    | HASARGS
                   | IS_REQUIRE | EVALTEXT | HINTS | BITMASK |
                ));
 
+   my $pipe = q{|};
    foreach my $c ( reverse @{$callers} ) {
       $table->load(
          [
-           '|', $c->{context},
-           '|', $c->{sub},
-           '|', $c->{line},
-           '|', $c->{file},
-           '|', $c->{hasargs},
-           '|', $c->{isreq},
-           '|', $c->{evaltext},
-           '|', $c->{hints},
-           '|', $c->{bitmask},
-           '|'
+           $pipe, $c->{context},
+           $pipe, $c->{sub},
+           $pipe, $c->{line},
+           $pipe, $c->{file},
+           $pipe, $c->{hasargs},
+           $pipe, $c->{isreq},
+           $pipe, $c->{evaltext},
+           $pipe, $c->{hints},
+           $pipe, $c->{bitmask},
+           $pipe
          ],
       );
    }
 
-   my $name = $opt->{name} ? "FOR $opt->{name} " : "";
+   my $name = $opt->{name} ? "FOR $opt->{name} " : EMPTY_STRING;
    my $top  = qq{| DUMPING CALLER STACK $name |\n};
 
-   my $rv   = "\n" . ( '-' x (length($top) - 1) ) . "\n" . $top
-            . $table->rule( '-', '+')
+   my $rv   = qq{\n} . ( q{-} x (length($top) - 1) ) . qq{\n} . $top
+            . $table->rule( qw( - + ) )
             . $table->title
-            . $table->rule( '-', '+')
+            . $table->rule( qw( - + ) )
             . $table->body
-            . $table->rule( '-', '+')
+            . $table->rule( qw( - + ) )
             ;
 
    return $rv;
@@ -197,8 +219,8 @@ Text::Template::Simple::Caller - Caller stack tracer
 
 =head1 DESCRIPTION
 
-This document describes version C<0.81> of C<Text::Template::Simple::Caller>
-released on C<13 September 2009>.
+This document describes version C<0.82> of C<Text::Template::Simple::Caller>
+released on C<30 May 2010>.
 
 Caller stack tracer for Text::Template::Simple. This module is not used
 directly inside templates. You must use the global template function
@@ -248,12 +270,12 @@ Burak Gursoy <burak@cpan.org>.
 
 =head1 COPYRIGHT
 
-Copyright 2004 - 2009 Burak Gursoy. All rights reserved.
+Copyright 2004 - 2010 Burak Gursoy. All rights reserved.
 
 =head1 LICENSE
 
 This library is free software; you can redistribute it and/or modify 
-it under the same terms as Perl itself, either Perl version 5.10.0 or, 
+it under the same terms as Perl itself, either Perl version 5.10.1 or, 
 at your option, any later version of Perl 5 you may have available.
 
 =cut
