@@ -1,22 +1,23 @@
 package Text::Template::Simple::Compiler::Safe;
 # Safe compiler. Totally experimental
 use strict;
+use warnings;
 use vars qw($VERSION);
 use Text::Template::Simple::Dummy;
 
-$VERSION = '0.81';
+$VERSION = '0.82';
 
-sub _compile { shift; return __PACKAGE__->_object->reval(shift) }
+sub compile { shift; return __PACKAGE__->_object->reval(shift) }
 
 sub _object {
    my $class = shift;
    if ( $class->can('object') ) {
       my $safe = $class->object;
-      if ( $safe && ref($safe) ) {
+      if ( $safe && ref $safe ) {
          return $safe if eval { $safe->isa('Safe'); 'Safe-is-OK' };
       }
-      my $end = $@ ? ': '.$@ : '.';
-      warn "Safe object failed. Falling back to default" . $end;
+      my $end = $@ ? q{: }.$@ : q{.};
+      warn 'Safe object failed. Falling back to default' . $end . "\n";
    }
    require Safe;
    my $safe = Safe->new('Text::Template::Simple::Dummy');
@@ -44,23 +45,27 @@ Private module.
 
 =head1 DESCRIPTION
 
-This document describes version C<0.81> of C<Text::Template::Simple::Compiler::Safe>
-released on C<13 September 2009>.
+This document describes version C<0.82> of C<Text::Template::Simple::Compiler::Safe>
+released on C<30 May 2010>.
 
 Safe template compiler.
 
+=head1 METHODS
+
+=head2 compile STRING
+
 =head1 AUTHOR
 
 Burak Gursoy <burak@cpan.org>.
 
 =head1 COPYRIGHT
 
-Copyright 2004 - 2009 Burak Gursoy. All rights reserved.
+Copyright 2004 - 2010 Burak Gursoy. All rights reserved.
 
 =head1 LICENSE
 
 This library is free software; you can redistribute it and/or modify 
-it under the same terms as Perl itself, either Perl version 5.10.0 or, 
+it under the same terms as Perl itself, either Perl version 5.10.1 or, 
 at your option, any later version of Perl 5 you may have available.
 
 =cut
