@@ -6,18 +6,19 @@ package Text::Template::Simple::Dummy;
 # and share package variables under strict (safe mode can
 # have problems though). See the Pod for more info.
 use strict;
+use warnings;
 use vars qw($VERSION);
 use Text::Template::Simple::Caller;
 use Text::Template::Simple::Util qw();
 
-$VERSION = '0.81';
+$VERSION = '0.82';
 
 sub stack { # just a wrapper
    my $opt = shift || {};
    Text::Template::Simple::Util::fatal('tts.caller.stack.hash')
       if ! Text::Template::Simple::Util::ishref($opt);
    $opt->{frame} = 1;
-   Text::Template::Simple::Caller->stack( $opt );
+   return Text::Template::Simple::Caller->stack( $opt );
 }
 
 1;
@@ -34,8 +35,8 @@ TODO
 
 =head1 DESCRIPTION
 
-This document describes version C<0.81> of C<Text::Template::Simple::Dummy>
-released on C<13 September 2009>.
+This document describes version C<0.82> of C<Text::Template::Simple::Dummy>
+released on C<30 May 2010>.
 
 All templates are compiled into this class.
 
@@ -63,12 +64,12 @@ Burak Gursoy <burak@cpan.org>.
 
 =head1 COPYRIGHT
 
-Copyright 2004 - 2009 Burak Gursoy. All rights reserved.
+Copyright 2004 - 2010 Burak Gursoy. All rights reserved.
 
 =head1 LICENSE
 
 This library is free software; you can redistribute it and/or modify 
-it under the same terms as Perl itself, either Perl version 5.10.0 or, 
+it under the same terms as Perl itself, either Perl version 5.10.1 or, 
 at your option, any later version of Perl 5 you may have available.
 
 =cut
